@@ -7,12 +7,17 @@
 #ifndef ALTERNATECALENDARPLUGIN_H
 #define ALTERNATECALENDARPLUGIN_H
 
-#include <memory>
+#include <QDate>
+
+#include <KConfigGroup>
+#include <KConfigWatcher>
 
 #include <CalendarEvents/CalendarEventsPlugin>
 
 #include "calendarsystem.h"
 
+class AbstractCalendarProvider;
+
 class AlternateCalendarPlugin : public CalendarEvents::CalendarEventsPlugin
 {
     Q_OBJECT
@@ -26,13 +31,26 @@ public:
     void loadEventsForDateRange(const QDate &startDate, const QDate &endDate) override;
 
 public Q_SLOTS:
-    void updateSettings();
+    void updateSettings(const KConfigGroup &configGroup);
 
 private:
-    const std::unique_ptr<class AlternateCalendarPluginPrivate> d;
+    void init();
+    void emitDataChangedSignal();
 
     QDate m_lastStartDate;
     QDate m_lastEndDate;
+    AbstractCalendarProvider *m_provider = nullptr;
+
+    // Cache lookup data
+    QHash<QDate, QCalendar::YearMonthDay> m_alternateDateCache;
+    QHash<QDate, SubLabel> m_sublabelCache;
+
+    // For updating config
+    KConfigGroup m_generalConfigGroup;
+    KConfigWatcher::Ptr m_configWatcher;
+
+    CalendarSystem::System m_calendarSystem = CalendarSystem::Gregorian;
+    int m_dateOffset = 0; // For the (tabular) Islamic Civil calendar
 };
 
 #endif
